import cx from "clsx";
import { prop } from "ramda";
import { mergeProps } from "solid-js";
import classes from "./ActionIcon.module.css";

/**
 * @typedef {object} ActionIconProps
 * @property {"s" | "m" | "l" | "xl" | "xxl"} [size]
 * @property {"filled" | "subtle" | "transparent"} [variant]
 * @property {"primary" | "secondary" | "danger" | "warn" | "success" | "info"} [color]
 * @property {string[]} [additionalClasses]
 * @property {JSX.EventHandler<HTMLButtonElement, PointerEvent>} [onClick]
 */

/**
 * @param {import("solid-js").ParentProps<ActionIconProps>} props
 */
export default function ActionIcon(props) {
  const mergedProps = mergeProps(
    {
      size: "m",
      color: "secondary",
      variant: "transparent",
      additionalClasses: [],
      onClick: (e) => {},
    },
    props
  );
  return (
    <button
      class={cx(
        prop("action-icon-button", classes),
        prop(`size-${mergedProps.size}`, classes),
        prop(`variant-${mergedProps.variant}`, classes),
        prop(`color-${mergedProps.color}`, classes),
        ...mergedProps.additionalClasses
      )}
      onClick={mergedProps.onClick}
    >
      {mergedProps.children}
    </button>
  );
}
